@@ -1,5 +1,5 @@
 assertGrunt.success();
 
 const content = fs.readFileSync(path.join(cwd, 'output.js'), 'utf-8');
-t.regex(content, /console\.log\("dokey"\);/);
+t.regex(content, /console\.log\("dokey"\)/);
 
